@@ -7,13 +7,13 @@ This module implements specialized container datatypes for CKIPNLP.
 
 __author__ = 'Mu Yang <http://muyang.pro>'
 __copyright__ = '2018-2020 CKIP Lab'
-__license__ = 'CC BY-NC-SA 4.0'
+__license__ = 'GPL-3.0'
 
 from .text import *
 from .seg import *
 from .ner import *
-from .parsed import *
+from .parse import *
 from .coref import *
 
 from .util.wspos import *
-from .util.parsed_tree import *
+from .util.parse_tree import *
