@@ -7,7 +7,7 @@ This module provides containers for NER sentences.
 
 __author__ = 'Mu Yang <http://muyang.pro>'
 __copyright__ = '2018-2020 CKIP Lab'
-__license__ = 'CC BY-NC-SA 4.0'
+__license__ = 'GPL-3.0'
 
 from typing import (
     NamedTuple as _NamedTuple,
@@ -48,17 +48,6 @@ class NerToken(_BaseTuple, _NerToken):
         Text format
             Not implemented
 
-        Dict format
-            Used for :meth:`from_dict` and :meth:`to_dict`.
-
-            .. code-block:: python
-
-                {
-                    'word': '中文字',   # token word
-                    'ner': 'LANGUAGE', # NER-tag
-                    'idx': (0, 3),     # starting / ending index.
-                }
-
         List format
             Used for :meth:`from_list` and :meth:`to_list`.
 
@@ -70,6 +59,17 @@ class NerToken(_BaseTuple, _NerToken):
                     (0, 3),     # starting / ending index.
                 ]
 
+        Dict format
+            Used for :meth:`from_dict` and :meth:`to_dict`.
+
+            .. code-block:: python
+
+                {
+                    'word': '中文字',   # token word
+                    'ner': 'LANGUAGE', # NER-tag
+                    'idx': (0, 3),     # starting / ending index.
+                }
+
         CkipTagger format
             Used for :meth:`from_tagger` and :meth:`to_tagger`.
 
@@ -83,6 +83,9 @@ class NerToken(_BaseTuple, _NerToken):
                 )
     """
 
+    def __new__(cls, word, ner, idx, **kwargs):  # pylint: disable=signature-differs
+        return super().__new__(cls, word, ner, tuple(idx), **kwargs)
+
     to_text = NotImplemented
     from_text = NotImplemented
 
@@ -108,16 +111,6 @@ class NerSentence(_BaseSentence):
         Text format
             Not implemented
 
-        Dict format
-            Used for :meth:`from_dict` and :meth:`to_dict`.
-
-            .. code-block:: python
-
-                [
-                    { 'word': '美國', 'ner': 'GPE', 'idx': (0, 2), },   # name-entity 1
-                    { 'word': '參議院', 'ner': 'ORG', 'idx': (3, 5), }, # name-entity 2
-                ]
-
         List format
             Used for :meth:`from_list` and :meth:`to_list`.
 
@@ -128,6 +121,16 @@ class NerSentence(_BaseSentence):
                     [ '參議院', 'ORG', (3, 5), ], # name-entity 2
                 ]
 
+        Dict format
+            Used for :meth:`from_dict` and :meth:`to_dict`.
+
+            .. code-block:: python
+
+                [
+                    { 'word': '美國', 'ner': 'GPE', 'idx': (0, 2), },   # name-entity 1
+                    { 'word': '參議院', 'ner': 'ORG', 'idx': (3, 5), }, # name-entity 2
+                ]
+
         CkipTagger format
             Used for :meth:`from_tagger` and :meth:`to_tagger`.
 
@@ -165,21 +168,6 @@ class NerParagraph(_BaseList):
         Text format
             Not implemented
 
-        Dict format
-            Used for :meth:`from_dict` and :meth:`to_dict`.
-
-            .. code-block:: python
-
-                [
-                    [ # Sentence 1
-                        { 'word': '中文字', 'ner': 'LANGUAGE', 'idx': (0, 3), },
-                    ],
-                    [ # Sentence 2
-                        { 'word': '美國', 'ner': 'GPE', 'idx': (0, 2), },
-                        { 'word': '參議院', 'ner': 'ORG', 'idx': (3, 5), },
-                    ],
-                ]
-
         List format
             Used for :meth:`from_list` and :meth:`to_list`.
 
@@ -195,6 +183,21 @@ class NerParagraph(_BaseList):
                     ],
                 ]
 
+        Dict format
+            Used for :meth:`from_dict` and :meth:`to_dict`.
+
+            .. code-block:: python
+
+                [
+                    [ # Sentence 1
+                        { 'word': '中文字', 'ner': 'LANGUAGE', 'idx': (0, 3), },
+                    ],
+                    [ # Sentence 2
+                        { 'word': '美國', 'ner': 'GPE', 'idx': (0, 2), },
+                        { 'word': '參議院', 'ner': 'ORG', 'idx': (3, 5), },
+                    ],
+                ]
+
         CkipTagger format
             Used for :meth:`from_tagger` and :meth:`to_tagger`.
 
