@@ -7,7 +7,7 @@ This module provides containers for text sentences.
 
 __author__ = 'Mu Yang <http://muyang.pro>'
 __copyright__ = '2018-2020 CKIP Lab'
-__license__ = 'CC BY-NC-SA 4.0'
+__license__ = 'GPL-3.0'
 
 from .base import (
     BaseList0 as _BaseList0
@@ -20,15 +20,15 @@ class TextParagraph(_BaseList0):
 
     .. admonition:: Data Structure Examples
 
-        Text/Dict/List format
-            Used for :meth:`from_text`, :meth:`to_text`, :meth:`from_dict`, :meth:`to_dict`, :meth:`from_list`, and
-            :meth:`to_list`.
+        Text/List/Dict format
+            Used for :meth:`from_text`, :meth:`to_text`, :meth:`from_list`, :meth:`to_list`, :meth:`from_dict`, and
+            :meth:`to_dict`.
 
             .. code-block:: python
 
                 [
-                    '中文字喔', # Sentence 1
-                    '啊哈哈哈', # Sentence 2
+                    '中文字耶，啊哈哈哈。',    # Sentence 1
+                    '「完蛋了！」畢卡索他想', # Sentence 2
                 ]
     """
 
