@@ -7,12 +7,7 @@ This module implements CKIPNLP drivers.
 
 __author__ = 'Mu Yang <http://muyang.pro>'
 __copyright__ = '2018-2020 CKIP Lab'
-__license__ = 'CC BY-NC-SA 4.0'
-
-from .base import (
-    DriverType,
-    DriverFamily,
-)
+__license__ = 'GPL-3.0'
 
 from .tagger import (
     CkipTaggerWordSegmenter,
@@ -22,7 +17,8 @@ from .tagger import (
 
 from .classic import (
     CkipClassicWordSegmenter,
-    CkipClassicSentenceParser,
+    CkipClassicConParser,
+    CkipClassicConParserClient,
 )
 
 from .ss import (
