@@ -7,7 +7,7 @@ This module provides built-in sentence segmentation driver.
 
 __author__ = 'Mu Yang <http://muyang.pro>'
 __copyright__ = '2018-2020 CKIP Lab'
-__license__ = 'CC BY-NC-SA 4.0'
+__license__ = 'GPL-3.0'
 
 import re as _re
 
@@ -17,8 +17,6 @@ from ckipnlp.container import (
 
 from .base import (
     BaseDriver as _BaseDriver,
-    DriverType as _DriverType,
-    DriverFamily as _DriverFamily,
 )
 
 ################################################################################################################################
@@ -29,13 +27,13 @@ class CkipSentenceSegmenter(_BaseDriver):  # pylint: disable=too-few-public-meth
     Arguments
     ---------
         lazy : bool
-            Lazy initialize underlay object.
+            Lazy initialize the driver.
         delims : str
             The delimiters.
         keep_delims : bool
-            Keep delimiters.
+            Keep the delimiters.
 
-    .. py:method:: __call__(*, raw, keep_all=True)
+    .. method:: __call__(*, raw, keep_all=True)
 
         Apply sentence segmentation.
 
@@ -46,10 +44,11 @@ class CkipSentenceSegmenter(_BaseDriver):  # pylint: disable=too-few-public-meth
             **text** (:class:`TextParagraph <ckipnlp.container.text.TextParagraph>`) — The sentences.
     """
 
-    driver_type = _DriverType.SENTENCE_SEGMENTER
-    driver_family = _DriverFamily.BUILTIN
+    driver_type = 'sentence_segmenter'
+    driver_family = 'default'
+    driver_inputs = ('raw',)
 
-    def __init__(self, *, lazy=False, delims=',，。!！?？:：;；\n', keep_delims=False):
+    def __init__(self, *, lazy=False, delims='\n', keep_delims=False):
         super().__init__(lazy=lazy)
 
         self.delims = delims
