@@ -7,7 +7,7 @@ This module provides drivers with CkipTagger backend.
 
 __author__ = 'Mu Yang <http://muyang.pro>'
 __copyright__ = '2018-2020 CKIP Lab'
-__license__ = 'CC BY-NC-SA 4.0'
+__license__ = 'GPL-3.0'
 
 from ckipnlp.container import (
     TextParagraph as _TextParagraph,
@@ -21,8 +21,6 @@ from ckipnlp.util.data import (
 
 from .base import (
     BaseDriver as _BaseDriver,
-    DriverType as _DriverType,
-    DriverFamily as _DriverFamily,
 )
 
 ################################################################################################################################
@@ -33,7 +31,7 @@ class CkipTaggerWordSegmenter(_BaseDriver):
     Arguments
     ---------
         lazy : bool
-            Lazy initialize underlay object.
+            Lazy initialize the driver.
         disable_cuda : bool
             Disable GPU usage.
         recommend_lexicons: Mapping[str, float]
@@ -48,7 +46,7 @@ class CkipTaggerWordSegmenter(_BaseDriver):
             (Please refer https://github.com/ckiplab/ckiptagger#4-run-the-ws-pos-ner-pipeline for details.)
 
 
-    .. py:method:: __call__(*, text)
+    .. method:: __call__(*, text)
 
         Apply word segmentation.
 
@@ -59,8 +57,9 @@ class CkipTaggerWordSegmenter(_BaseDriver):
             **ws** (:class:`TextParagraph <ckipnlp.container.text.TextParagraph>`) — The word-segmented sentences.
     """
 
-    driver_type = _DriverType.WORD_SEGMENTER
-    driver_family = _DriverFamily.TAGGER
+    driver_type = 'word_segmenter'
+    driver_family = 'tagger'
+    driver_inputs = ('text',)
 
     def __init__(self, *, lazy=False, disable_cuda=True, recommend_lexicons={}, coerce_lexicons={}, **opts):
         super().__init__(lazy=lazy)
@@ -87,13 +86,15 @@ class CkipTaggerWordSegmenter(_BaseDriver):
 
         return ws
 
+################################################################################################################################
+
 class CkipTaggerPosTagger(_BaseDriver):
     """The CKIP part-of-speech tagging driver with CkipTagger backend.
 
     Arguments
     ---------
         lazy : bool
-            Lazy initialize underlay object.
+            Lazy initialize the driver.
         disable_cuda : bool
             Disable GPU usage.
 
@@ -103,7 +104,7 @@ class CkipTaggerPosTagger(_BaseDriver):
             Extra options for :meth:`ckiptagger.POS.__call__`.
             (Please refer https://github.com/ckiplab/ckiptagger#4-run-the-ws-pos-ner-pipeline for details.)
 
-    .. py:method:: __call__(*, text)
+    .. method:: __call__(*, text)
 
         Apply part-of-speech tagging.
 
@@ -114,8 +115,9 @@ class CkipTaggerPosTagger(_BaseDriver):
             **pos** (:class:`TextParagraph <ckipnlp.container.text.TextParagraph>`) — The part-of-speech sentences.
     """
 
-    driver_type = _DriverType.POS_TAGGER
-    driver_family = _DriverFamily.TAGGER
+    driver_type = 'pos_tagger'
+    driver_family = 'tagger'
+    driver_inputs = ('ws',)
 
     def __init__(self, *, lazy=False, disable_cuda=True, **opts):
         super().__init__(lazy=lazy)
@@ -134,13 +136,15 @@ class CkipTaggerPosTagger(_BaseDriver):
 
         return pos
 
+################################################################################################################################
+
 class CkipTaggerNerChunker(_BaseDriver):
     """The CKIP named-entity recognition driver with CkipTagger backend.
 
     Arguments
     ---------
         lazy : bool
-            Lazy initialize underlay object.
+            Lazy initialize the driver.
         disable_cuda : bool
             Disable GPU usage.
 
@@ -150,7 +154,7 @@ class CkipTaggerNerChunker(_BaseDriver):
             Extra options for :meth:`ckiptagger.NER.__call__`.
             (Please refer https://github.com/ckiplab/ckiptagger#4-run-the-ws-pos-ner-pipeline for details.)
 
-    .. py:method:: __call__(*, text)
+    .. method:: __call__(*, text)
 
         Apply named-entity recognition.
 
@@ -162,8 +166,9 @@ class CkipTaggerNerChunker(_BaseDriver):
             **ner** (:class:`NerParagraph <ckipnlp.container.ner.NerParagraph>`) — The named-entity recognition results.
     """
 
-    driver_type = _DriverType.NER_CHUNKER
-    driver_family = _DriverFamily.TAGGER
+    driver_type = 'ner_tagger'
+    driver_family = 'tagger'
+    driver_inputs = ('ws', 'pos',)
 
     def __init__(self, *, lazy=False, disable_cuda=True, **opts):
         super().__init__(lazy=lazy)
