@@ -7,14 +7,9 @@ This module implements CKIPNLP pipelines.
 
 __author__ = 'Mu Yang <http://muyang.pro>'
 __copyright__ = '2018-2020 CKIP Lab'
-__license__ = 'CC BY-NC-SA 4.0'
+__license__ = 'GPL-3.0'
 
-from ..driver.base import (
-    DriverType,
-    DriverFamily,
-)
-
-from .core import (
+from .kernel import (
     CkipPipeline,
     CkipDocument,
 )
